---
search:
  exclude: true
---
# コード例

[repo](https://github.com/openai/openai-agents-python/tree/main/examples) の examples セクションで、SDK のさまざまなサンプル実装をご覧ください。コード例は、異なるパターンや機能を示す複数のカテゴリーに整理されています。

## カテゴリー

- **[agent_patterns](https://github.com/openai/openai-agents-python/tree/main/examples/agent_patterns):**
  このカテゴリーの例では、一般的なエージェント設計パターンを紹介します。例えば

    - 決定的なワークフロー
    - ツールとしてのエージェント
    - エージェントの並列実行

- **[basic](https://github.com/openai/openai-agents-python/tree/main/examples/basic):**
  SDK の基礎的な機能を紹介します。例えば

    - 動的な システムプロンプト
    - ストリーミング出力
    - ライフサイクルイベント

- **[tool examples](https://github.com/openai/openai-agents-python/tree/main/examples/tools):**
  Web 検索 や ファイル検索 などの OpenAI がホストするツールの実装方法と、それらをエージェントに統合する方法を学びます。

- **[model providers](https://github.com/openai/openai-agents-python/tree/main/examples/model_providers):**
  SDK で OpenAI 以外のモデルを使う方法を紹介します。

- **[handoffs](https://github.com/openai/openai-agents-python/tree/main/examples/handoffs):**
  エージェントのハンドオフの実用的な例をご覧ください。

- **[mcp](https://github.com/openai/openai-agents-python/tree/main/examples/mcp):**
  MCP でエージェントを構築する方法を学びます。

- **[customer_service](https://github.com/openai/openai-agents-python/tree/main/examples/customer_service)** と **[research_bot](https://github.com/openai/openai-agents-python/tree/main/examples/research_bot):**
  実運用に近いアプリケーションを示す、より作り込まれたコード例が 2 つあります

    - **customer_service**: 航空会社向けのカスタマーサービス システムの例。
    - **research_bot**: シンプルな ディープリサーチ のクローン。

- **[voice](https://github.com/openai/openai-agents-python/tree/main/examples/voice):**
  TTS と STT のモデルを用いた音声エージェントの例をご覧ください。

- **[realtime](https://github.com/openai/openai-agents-python/tree/main/examples/realtime):**
  SDK を使ってリアルタイム体験を構築する方法の例です。